@@ -2,8 +2,9 @@
   Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,7 +27,7 @@ class AutoCorrectionListWidget : public QListWidget
     Q_OBJECT
 public:
     explicit AutoCorrectionListWidget(QWidget *parent = nullptr);
-    ~AutoCorrectionListWidget();
+    ~AutoCorrectionListWidget() override;
 
 protected:
     void keyPressEvent(QKeyEvent *event) override;
